@@ -4,6 +4,7 @@
 #define import_spp
 #define import_libc
 #define import_stdio
+#define import_ctype
 #include <iraf.h>
 
 #include "config.h"
@@ -47,12 +48,7 @@ char	*loc_field = "Attempt to access undefined field in local variable %s.\n";
  *   Depend on this and don't check for ERR; beware if change it.
  */
 struct param *
-paramfind (
-  struct pfile *pfp,
-  char	*pname,
-  int	pos, 
-  int   exact
-)
+paramfind (struct pfile *pfp, char *pname, int pos, int exact)
 {
 	register char first_char;
 	register struct	param *pp;
@@ -142,10 +138,7 @@ paramfind (
  *	order of interpolator (3|5|7) (5):
  */
 void
-paramset (
-  register struct param *pp,
-  char	field
-)
+paramset (register struct param *pp, char field)
 {
 	struct	operand o;
 	int	bastype;	/* OT_BASIC portion of p_type		*/
@@ -365,10 +358,7 @@ paramset (
  * or if pp is out of range.  Call error if return value would be undefined.
  */
 void
-validparamget (
-  register struct param *pp,
-  char	field
-)
+validparamget (register struct param *pp, char field)
 {
 	struct operand o;
 
@@ -389,10 +379,7 @@ validparamget (
  * is out of range.  Value returned may be undefined.
  */
 void
-paramget (
-  register struct param *pp,
-  char	field
-)
+paramget (register struct param *pp, char field)
 {
 	char	mode[5];	/* used to turn bits into string	*/
 	struct	operand result;
@@ -600,6 +587,7 @@ paramget (
 	 */
 	if ((result.o_type & OT_BASIC) == OT_STRING &&
 	    *result.o_val.v_s == PF_INDIRECT) {
+
 	    char	redir[SZ_FNAME];
 	    struct	param *np;
 	    char	*pk, *t, *p, *f;
@@ -644,10 +632,7 @@ paramget (
  * (impossible) worse case.
  */
 void
-makemode (
-  struct param *pp,
-  char	*s
-)
+makemode (struct param *pp, char *s)
 {
 	register int m = pp->p_mode;
 
@@ -671,9 +656,7 @@ makemode (
  * Null out all unused fields except the three union values.
  */
 struct param *
-newparam (
-  struct pfile *pfp
-)
+newparam (struct pfile *pfp)
 {
 	register struct param *newpp;
 
@@ -718,11 +701,7 @@ newparam (
  * Call error() and do not return if cannot find it.
  */
 struct param *
-paramsrch (
-  char	*pkname, 
-  char  *ltname, 
-  char  *pname
-)
+paramsrch (char *pkname, char *ltname, char *pname)
 {
 	register struct param *pp;
 	struct	pfile *pfp;
@@ -815,11 +794,7 @@ defvar (char *envvar)
  * Called by PARAMSRCH and by DEFPAR.
  */
 struct param *
-lookup_param (
-  char	*pkname, 
-  char  *ltname, 
-  char  *pname
-)
+lookup_param (char *pkname, char *ltname, char *pname)
 {
 	register struct param *pp;
 	register struct package *pkp;
@@ -865,13 +840,14 @@ lookup_param (
 		for (i=0;  i <= 1;  i++)
 		    if ((pfp = pfp_head[i]) != NULL) {
 			pfiles[npfiles++] = pfp;
-			if (pfp->pf_flags & PF_PSETREF)
-			    while ((pfp = pfp->pf_npset)) {
+			if (pfp->pf_flags & PF_PSETREF) {
+			    while ( (pfp = pfp->pf_npset) ) {
 				pfiles[npfiles++] = pfp;
 				if (npfiles >= 62)
 				    cl_error (E_IERR,
 					"lookup_param: too many pfiles");
 			    }
+			}
 		    }
 	    }
 
@@ -893,7 +869,7 @@ lookup_param (
 		    } else if (!strcmp (pp->p_name, pname)) {
 			ambig = 0;
 			break;			/* exact match */
-                    } else if (candidate != NULL && candidate != pp) {
+		    } else if (candidate != NULL && candidate != pp) {
 			ambig++;
 		    } else {
 			candidate = pp;
@@ -957,17 +933,14 @@ lookup_param (
  * Don't call error() so caller can have a chance to close the file.
  */
 int
-printparam (
-  struct   param *pp,
-  register FILE *fp
-)
+printparam (struct param *pp, register FILE *fp)
 {
 	register int type, bastype;
 	register char *bp;
 	char	*index();
 	char	buf[20];
 	int	arrflag;
-	int	size_arr;
+	int	size_arr=0;
 	int	i;		/* a misc variable.	*/
 
 	if ((pp->p_mode & M_FAKE) && fp != stderr)
@@ -1141,9 +1114,9 @@ printparam (
 	    /* For a first approximation use a fixed number of
 	     * values per line.
 	     */
-	    int    count, lcount, n_per, *p_i;
-	    double *p_r;
-	    char   **p_s;
+	    int    count=0, lcount=0, n_per=0, *p_i= NULL;
+	    double *p_r= NULL;
+	    char   **p_s = NULL;
 
 	    if (bastype == OT_BOOL) {
 		n_per = 20;
@@ -1214,10 +1187,7 @@ printparam (
  * sequences, so that they can later be read back in unmodified.
  */
 void
-qputs (
-  register char	*str,
-  register FILE	*fp
-)
+qputs (register char *str, register FILE *fp)
 {
 	register char	ch;
 
@@ -1262,10 +1232,7 @@ qputs (
  * value.
  */
 int
-pvaldefined (
-  struct param *pp,
-  char	*s
-)
+pvaldefined (struct param *pp, char *s)
 {
 	int val;
 
@@ -1289,11 +1256,11 @@ pvaldefined (
  */
 struct param *
 newfakeparam (
-  struct pfile *pfp,
-  char	*name,
-  int	pos, 
-  int   type,
-  int	string_len 	/* if new param is type string, size of string */
+    struct pfile *pfp,
+    char *name,
+    int pos,
+    int type,
+    int string_len	/* if new param is type string, size of string */
 )
 {
 	register struct param *pp;
@@ -1310,7 +1277,7 @@ newfakeparam (
 	if (cldebug)
 	    eprintf ("adding fake param `%s', type code %d\n",
 		pp->p_name, type);
-	    
+
 	type &= OT_BASIC;
 	pp->p_valo.o_type = type;
 	pp->p_mino.o_type = type;
@@ -1338,9 +1305,7 @@ newfakeparam (
  * for using the index values stored on the stack.
  */
 int
-getoffset (
-  struct param	*pp
-)
+getoffset (struct param *pp)
 {
 	int	dim, offset, index;
 	short	*plen, *poff, len, off;
@@ -1402,9 +1367,7 @@ offsetmode (int mode)
 /* SIZE_ARRAY -- Get the number of elements in an array.
  */
 int
-size_array (
-  struct param *pp
-)
+size_array (struct param *pp)
 {
 	int dim, d, size;
 	short *len;
