@@ -14,6 +14,7 @@
 #define import_xnames
 #include <iraf.h>
 
+#include <ctype.h>
 #include "config.h"
 #include "grammar.h"
 #include "opcodes.h"
@@ -52,9 +53,9 @@ typedef	int (*PFI)();
 
 extern	int yydebug;		/* print each parser state if set	*/
 extern	FILE *yyin;		/* where parser reads from		*/
-extern	yeof;			/* set when yacc sees eof 		*/
-extern	dobkg;			/* set when code is to be done in bkg	*/
-extern	bkgno;			/* job number if bkg job		*/
+extern	int yeof;		/* set when yacc sees eof 		*/
+extern	int dobkg;		/* set when code is to be done in bkg	*/
+extern	int bkgno;		/* job number if bkg job		*/
 
 int	cldebug = 0;		/* print out lots of goodies if > 0	*/
 int	cltrace = 0;		/* trace instruction execution if > 0	*/
@@ -69,6 +70,7 @@ memel	cl_dictbuf[DICTSIZE];	/* the dictionary area			*/
 
 jmp_buf errenv;			/* cl_error() jumps here		*/
 jmp_buf intenv;			/* X_INT during process jumps here	*/
+jmp_buf child_startup;		/* child processes jump here            */
 int	validerrenv;		/* stays 0 until errenv gets set	*/
 int	loggingout;		/* set while processing logout file	*/
 int	gologout;		/* set when logout() is typed		*/
@@ -79,14 +81,17 @@ int	ninterrupts;		/* number of onint() calls per task	*/
 int	currentline;		/* current line being executed		*/
 int	errorline;		/* error line being recovered		*/
 long	cpustart, clkstart;	/* starting cpu, clock times if bkg	*/
-int	logout_status = 0;	/* optional status arg to logout() 	*/
+int	logout_status = 0;	/* optional status arg to logout()	*/
 
-static  void execute();
-static  void login(), logout();
-static  void startup(), shutdown();
+
+static void execute();
+static void login(), logout();
+static void startup(), shutdown();
 static  char *file_concat (char  *in1, char  *in2);
 
-	
+extern void c_xwhen(), onint();
+extern int yyparse();
+
 static  char *tmpfile = NULL;
 extern	char epar_cmdbuf[];
 
@@ -96,10 +101,10 @@ extern	char epar_cmdbuf[];
  * the file system, etc. is initialized.  When we exit we signal that the
  * interpreter be skipped, proceeding directly to process shutdown.
  */
-c_main (prtype, bkgfile, cmd)
-int	*prtype;		/* process type (connected, detached)	*/
-PKCHAR	*bkgfile;		/* bkgfile filename if detached		*/
-PKCHAR	*cmd;			/* host command line			*/
+int
+c_main (
+  PKCHAR *cmd 			/* host command line			*/
+)
 {
 	XINT	bp;
 
@@ -120,9 +125,7 @@ PKCHAR	*cmd;			/* host command line			*/
 	 * these fail.
 	 */
 	startup ();
-
-	if (*prtype == PR_DETACHED) {
-	    bkg_startup ((char *)bkgfile);
+	if (setjmp(child_startup)) {
 	    cpustart = c_cputime (0L);
 	    clkstart = c_clktime (0L);
 	    execute (BACKGROUND);
@@ -151,7 +154,7 @@ exit_:
 /* CLEXIT -- Called on fatal error from error() when get an error so bad that we
  * should commit suicide.
  */
-int 
+void
 clexit (void)
 {
 	longjmp (jmp_clexit, 1);
@@ -160,7 +163,7 @@ clexit (void)
 
 /* CLSHUTDOWN -- Public entry for shutdown.
  */
-int 
+void
 clshutdown (void)
 {
 	shutdown();
@@ -179,19 +182,11 @@ clshutdown (void)
  *   a buffer.  A simple binary copy of the dictionary to different region
  *   of memory in the bkg CL will leave the pointers pointing into limbo.
  *
- * TODO: Write a pair of procedures for each major data structure to dump
- *   and restore the data structure in a binary array.  Passing the CL context
- *   to the bkg CL would then be a matter of calling the dump procedure for
- *   each major data structure to dump the structure into the bkgfile, then
- *   doing a matching restore in the bkg CL to restore the data structure
- *   to a different region of memory.  The ENV package does this already.
- *   The only alternative would be to use indices rather than pointers in
- *   the dictionary, which is not what C likes to do.
  */
-static void 
+static void
 startup (void)
 {
-	int	onint(), onipc();
+	void	onipc();
 
 	/* Set up pointers to dictionary buffer.
 	 */
@@ -224,7 +219,7 @@ startup (void)
  * Don't bother with restor'ing if BATCH since we don't want to write out
  *   anything then anyway.
  */
-static void 
+static void
 shutdown (void)
 {
 	float	cpu, clk;
@@ -240,7 +235,6 @@ shutdown (void)
 		fprintf (stderr, "\n[%d] done  %.1f %.0m %d%%\n", bkgno,
 		    cpu, clk/60., (int)((clk > 0 ? cpu / clk : 0.) * 100.));
 	    }
-
 	} else {
 	    firstask->t_topd = dereference (firstask->t_ltp) + LTASKSIZ;
 	    restor (firstask);
@@ -262,13 +256,12 @@ shutdown (void)
  * mode, we skip the preliminaries and jump right in and interpret the
  * compiled code.
  */
-static void 
+static void
 execute (int mode)
 {
 	int	parsestat;
 	XINT	old_parhead;
 	char	*curcmd();
-	extern  char *onerr_handler;
 
 	alldone = 0;
 	gologout = 0;
@@ -370,7 +363,7 @@ bkg:
  * Add the builtin function ltasks.  Run the startup file as the stdin of cl.
  * If any of this fails, we die.
  */
-static void 
+static void
 login (char *cmd)
 { 
 	register struct task *tp;
@@ -501,7 +494,6 @@ login (char *cmd)
 	    }
 	}
 
-
 	/* Copy any user supplied host command line arguments into the
 	 * CL parameter $args to use in the startup script (for instance).
 	 */
@@ -625,7 +617,7 @@ file_concat (char  *in1, char  *in2)
  * of the CL is hooked to the system logout file and when the eof of the
  * logout file is seen the CL really does exit.
  */
-static void 
+static void
 logout (void)
 { 
 	register struct task *tp;
@@ -653,7 +645,7 @@ logout (void)
  */
 char *
 memneed (
-    int incr		/* amount of space desired in ints, not bytes	*/
+  int	incr 		/* amount of space desired in ints, not bytes	*/
 )
 {
 	memel *old;
@@ -684,10 +676,10 @@ memneed (
  *   before shutting down.
  */
 /* ARGSUSED */
-int 
+void
 onint (
-    int *vex,			/* virtual exception code	*/
-    int (**next_handler)(void)	/* next handler to be called	*/
+  int	*vex,			/* virtual exception code	*/
+  int	(**next_handler)(void) 	/* next handler to be called	*/
 )
 {
 	if (firstask->t_flags & T_BATCH) {
@@ -745,7 +737,7 @@ onint (
 /* INTR_DISABLE -- Disable interrupts, e.g., to protect a critical section
  * of code.
  */
-int 
+void
 intr_disable (void)
 {
 	PFI	junk;
@@ -760,7 +752,7 @@ intr_disable (void)
 /* INTR_ENABLE -- Reenable interrupts, reposting the interrupt vector saved
  * in a prior call to INTR_DISABLE.
  */
-int 
+void
 intr_enable (void)
 {
 	PFI	junk;
@@ -774,11 +766,10 @@ intr_enable (void)
 /* INTR_RESET -- Post the interrupt handler and clear the interrupt vector
  * save stack.
  */
-int 
+void
 intr_reset (void)
 {
 	PFI	junk;
-	int	onint();
 
 	c_xwhen (X_INT, onint, &junk);
 	intr_sp = 0;
@@ -793,11 +784,10 @@ intr_reset (void)
  * the system and call cl_error() which eventually does a longjmp back to
  * the errenv in execute().
  */
-int 
+void
 onerr (void)
 {
 	char	errmsg[SZ_LINE];
-	extern	int do_error;
 
 	c_erract (EA_RESTART);
 	c_errget (errmsg, SZ_LINE);
@@ -813,8 +803,12 @@ onerr (void)
 
 /* CL_AMOVI -- Copy an integer sized block of memory.
  */
-int 
-cl_amovi (register int *ip, register int *op, register int len)
+void
+cl_amovi (
+  register int	*ip,
+  register int	*op,
+  register int	len 
+)
 {
 	while (--len)
 	    *op++ = *ip++;
