@@ -1,21 +1,25 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
- */
+*/
 
 #define import_spp
 #define	import_libc
 #define	import_xnames
 #include <iraf.h>
 
+
 /* C_FMAPFN -- Map a VFN (virtual filename) into an OSFN (host system filename).
- */
-c_fmapfn (vfn, osfn, maxch)
-char	*vfn;			/* virtual filename		*/
-char	*osfn;			/* OS filename			*/
-int	maxch;
+*/
+int
+c_fmapfn (
+  char	*vfn,			/* virtual filename		*/
+  char	*osfn,			/* OS filename			*/
+  int	maxch
+)
 {
 	XCHAR	x_osfn[SZ_PATHNAME+1];
 	XINT	sz_path = SZ_PATHNAME;
 
+
 	/* The OSFN is returned as a packed string in the XCHAR array x_osfn.
 	 * An intermediate buffer is used to avoid char->xchar alignment
 	 * problems of upward pointer coercion on some machines.
@@ -24,7 +28,7 @@ int	maxch;
 	    iferr (FMAPFN (c_sppstr(vfn), x_osfn, &sz_path))
 		osfn[0] = EOS;
 	    else {
-		strncpy (osfn, (char *)x_osfn, maxch);
+		(void) strncpy (osfn, (char *)x_osfn, maxch);
 		osfn[maxch-1] = EOS;
 	    }
 	
