@@ -9,9 +9,10 @@
 
 /* C_FMKDIR -- FIO procedure to create a new directory.
 */
-int
-c_fmkdir (newdir)
-char	*newdir;			/* name of the new directory	*/
+int 
+c_fmkdir (
+    char *newdir			/* name of the new directory	*/
+)
 {
 	iferr (FMKDIR (c_sppstr(newdir)))
 	    return (ERR);
