@@ -22,7 +22,7 @@ extern	XCHAR text[];
 extern	XCHAR *txop;
 # endif
 
-char	*vfn2osfn();
-char	*osfn2vfn();
-char	*os_strpak();
-XCHAR	*os_strupk();
+char	*vfn2osfn(char *vfn, int new);
+char	*osfn2vfn(char *osfn);
+char	*os_strpak(short int *sppstr, char *cstr, int maxch);
+XCHAR	*os_strupk(char *str, short int *outstr, int maxch);
