@@ -14,7 +14,7 @@ os_cmd (char *cmd)
 	PKCHAR	x_cmd[SZ_CMD+1];
 	PKCHAR	nullstr[1];
 	XINT	status;
-	extern  int ZOSCMD();
+	extern  int ZOSCMD(PKCHAR *oscmd, PKCHAR *stdin_file, PKCHAR  *stdout_file, PKCHAR *stderr_file, XINT *status);
 
 
 	strncpy ((char *)x_cmd, cmd, SZ_CMD);
