@@ -3,9 +3,10 @@
 # the enternal dependency.  The filename lex.yy.c is changed to lexyy.c
 # for portability reasons.
 
-#if [ ! -f lexyy.c -o tok.l -nt lexyy.c ] ; then
-    lex -o lexyy.c tok.l
-#fi
+# Exit on error
+set -e
+
+flex -o lexyy.c tok.l
 
 $CC -c $HSI_CF	generic.c yywrap.c lexyy.c
 $CC $HSI_LF	generic.o lexyy.o yywrap.o $HSI_LIBS -o generic.e
