@@ -37,7 +37,6 @@ int	mlb_op = 0;			/* index into string buffer	*/
 int	mlb_index[MAX_LIBFILES];	/* sbuf indices for each symbol	*/
 long	mlb_fdate[MAX_LIBFILES];	/* file date of each module	*/
 int	mlb_modified;			/* modified flag		*/
-char	*mlb_filename();
 
 struct	dbentry {			/* module entry on disk		*/
 	long	fdate;
@@ -79,7 +78,6 @@ h_scanlibrary (char *library)
 	mlb_op = 1;
 	nmodules = 0;
 
-	len = 0;
 	for (i=0;  i < MAX_LIBFILES;  i++)
 	    mlb_index[i] = 0;
 
@@ -195,11 +193,11 @@ h_scanlibrary (char *library)
 		        char p[SZ_PATHNAME];
 
 		        len = atoi(&arf.ar_name[3]);
-	                bzero (p, SZ_PATHNAME);
+	                memset (p, 0, SZ_PATHNAME);
 		        if (fread(p, len, 1, fp) != 1) {
 		            fprintf (stderr, "%s: premature EOF", libfname);
 		        }
-	                bzero (modname, SZ_KEY+1);
+	                memset (modname, 0, SZ_KEY+1);
 		        sprintf (modname, "%s", p);
 	        } else 
 		    len = 0;
@@ -252,8 +250,8 @@ err:
 long
 h_ardate (char *fname)
 {
-	extern	char *makeobj();
-	long	mlb_getdate();
+	extern	char *makeobj(char *fname);
+	long	mlb_getdate(char *modname);
 
 	return (mlb_getdate (makeobj (fname)));
 }
