@@ -4,6 +4,13 @@
 # Exit on error
 set -e
 
+if [ "${RATFOR}" ] ; then
+    echo "------------------- Ratfor preprocessing ---------------"
+    rm -f rppfor/*.f ratlibf/*.f rpprat/fort ratlibr/fort
+    make -C rpprat RATFOR=${RATFOR}
+    make -C ratlibr RATFOR=${RATFOR}
+fi
+
 echo "----------------------- RPPFOR -------------------------"
 (cd rppfor;	sh -x mkpkg.sh)
 echo "----------------------- RATLIBF ------------------------"
