@@ -1,5 +1,9 @@
+#!/bin/sh
 # Utility library subroutines for RPP.
 
+# Exit on error
+set -e
+
 $F77 -c $HSI_FF	addset.f addstr.f amatch.f catsub.f clower.f concat.f
 $F77 -c $HSI_FF	ctoc.f ctoi.f ctomn.f cupper.f delete.f docant.f dodash.f
 $F77 -c $HSI_FF	dsdbiu.f dsdump.f dsfree.f dsget.f dsinit.f enter.f equal.f
@@ -12,7 +16,7 @@ $F77 -c $HSI_FF	scopy.f sctabl.f sdrop.f skipbl.f slstr.f stake.f stclos.f
 $F77 -c $HSI_FF	stcopy.f stlu.f strcmp.f strim.f termin.f trmout.f type.f
 $F77 -c $HSI_FF	upper.f wkday.f
 
-ar rv		libf.a *.o
+ar r		libf.a *.o
 $RANLIB		libf.a
 mv -f		libf.a ..
 rm		*.o
