@@ -1,5 +1,9 @@
+#!/bin/sh
 # Fortran source for RPP preprocessor.
 
+# Exit on error
+set -e
+
 $F77 -c $HSI_FF	addchr.f allblk.f alldig.f baderr.f balpar.f beginc.f
 $F77 -c $HSI_FF	brknxt.f cascod.f caslab.f declco.f deftok.f doarth.f
 $F77 -c $HSI_FF	docode.f doif.f doincr.f domac.f dostat.f dosub.f
@@ -16,7 +20,7 @@ $F77 -c $HSI_FF	repcod.f retcod.f sdupl.f skpblk.f squash.f strdcl.f
 $F77 -c $HSI_FF	swcode.f swend.f swvar.f synerr.f thenco.f ulstal.f
 $F77 -c $HSI_FF	uniqid.f unstak.f untils.f whilec.f whiles.f
 
-ar rv		librpp.a *.o
+ar r		librpp.a *.o
 $RANLIB		librpp.a
 mv -f		librpp.a ..
 rm		*.o
