@@ -11,6 +11,7 @@
 #include <dirent.h>
 #include <string.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include "xpp.h"
 #include "../bootProto.h"
 
@@ -40,7 +41,7 @@
 #define	SZ_PKGENV	256
 #define DEF_PKGENV	"iraf"
 
-#ifdef __APPLE__
+#if (defined (__APPLE__) || defined (__freebsd__))
 #define	CCOMP		"cc"			/* C compiler (also .s etc.) */
 #define	LINKER		"cc"			/* Linking utility */
 #define	F_STATIC	"-static"
@@ -72,13 +73,14 @@
 #define IRAFLIB5	"libVOTable.a"
 #define IRAFLIB6	"libcfitsio.a"
 #define IRAFLIB7	"liblapack.a"
+#define IRAFLIB8	"libfftpack.a"
 
 char *fortlib[] = { "-lf2c",			/*  0  (host progs) */
 		    "-lf2c",			/*  1  */
 		    "-lm",			/*  2  */
 		    "-lcurl",			/*  3  */
 		    "-lexpat",			/*  4  */
-#ifdef __linux__
+#if (defined (__linux__) || defined (__gnu_hurd__))
 		    "-lpthread",		/*  5  */
 #else
 		    "",				/*  5  */
@@ -190,10 +192,6 @@ static void  rmfiles (void);
 static void  fatalstr (char *s1, char *s2);
 static void  fatal (char *s);
 
-static char *findexe (char *prog, char *dir);
-
-
-
 
 /**
  *  MAIN -- Execution begins here.  Interpret command line arguments and
@@ -840,6 +838,7 @@ passflag:		    mkobject = YES;
 		arglist[nargs++] = mkfname (IRAFLIB7);
 		arglist[nargs++] = mkfname (IRAFLIB2);
 		arglist[nargs++] = mkfname (IRAFLIB3);
+		arglist[nargs++] = mkfname (IRAFLIB8);
 		arglist[nargs++] = mkfname (IRAFLIB4);
 		arglist[nargs++] = mkfname (IRAFLIB5);
 		arglist[nargs++] = mkfname (IRAFLIB6);
@@ -1198,7 +1197,6 @@ static int
 run (char *task, char *argv[])
 {
 	int	waitpid;
-	pid_t	fork();
 	char	path[SZ_PATHNAME];
 
 	if ((waitpid = fork()) == 0) {
@@ -1402,68 +1400,3 @@ fatal (char *s)
 	fflush (stderr);
 	done (1);
 }
-
-
-/* FINDEXE -- Search for the named file and return the path if found, else
- * NULL.  If "dir" is non-NULL the directory in which the file resides is
- * returned in the string buffer pointed to.  The user's PATH is searched,
- * followed by SYSBINDIR, then LOCALBINDIR.
- */
-static char *
-findexe (
-    char  *prog,		/* file to search for */
-    char  *dir			/* pointer to output string buf, or NULL */
-)
-{
-	register char *ip, *op;
-	static	char path[SZ_PATHNAME];
-	char	dirpath[SZ_PATHNAME];
-	char	*dp = dir ? dir : dirpath;
-	char	*pathp;
-
-	/* Look for the program in the directories in the user's path.
-	 */
-	ip = pathp = os_getenv ("PATH");
-	while (*ip) {
-	    for (op=dp;  *ip && (*op = *ip++) != ':';  op++)
-		;
-	    *op++ = '/';
-	    *op++ = EOS;
-	    strcpy (path, dp);
-	    strcat (path, prog);
-	    if (access (path, 0) != -1)
-		return (path);
-	}
-
-	/* Look in SYSBINDIR. */
-	strcpy (dp, SYSBINDIR);
-	strcpy (path, dp);
-	strcat (path, prog);
-
-	if (access (path, 0) != -1) {
-	    static  char envpath[8192];
-	    char    *oldpath;
-
-	    /* Add SYSBINDIR to the user's path.  This is required to
-	     * use the V1.3 compiler.  Note that this code should only be
-	     * executed once, since the next time findexe is called the
-	     * SYSBINDIR directory will be in the default path, above.
-	     */
-	    if ((oldpath = pathp)) {
-		sprintf (envpath, "PATH=%s:%s", SYSBINDIR, oldpath);
-		putenv (envpath);
-	    }
-
-	    return (path);
-	}
-
-	/* Look in LOCALBINDIR. */
-	strcpy (dp, LOCALBINDIR);
-	strcpy (path, dp);
-	strcat (path, prog);
-	if (access (path, 0) != -1)
-	    return (path);
-
-	/* Not found. */
-	return (NULL);
-}
