@@ -3,15 +3,15 @@
  */
 #ifndef D_libc
 #ifndef import_libc
-#include <libc.h>
+#include "libc.h"
 #endif
 #ifndef import_knames
-#include <knames.h>
+#include "knames.h"
 #endif
 #endif
 
 typedef	int	jmp_buf[LEN_JUMPBUF];
-static	int	u_jmpstat;
+static	XINT	u_jmpstat;
 
 #define	setjmp(e)	(ZSVJMP((e),&u_jmpstat),u_jmpstat)
 #define	longjmp(e,v)	(u_jmpstat=(v),ZDOJMP((e),&u_jmpstat))
@@ -19,7 +19,7 @@ static	int	u_jmpstat;
 /* The following is necessary to prevent to prevent the optimizer from
  * doing unwise things with setjmp on a Sun-4.
  */
-extern	zsvjmp_();
+extern	int zsvjmp_();
 #pragma unknown_control_flow(zsvjmp_)
 
 #define	D_setjmp
