@@ -7,19 +7,23 @@
 #define import_spp
 #include <iraf.h>
 
-char	oscwd[SZ_PATHNAME+1];		/* See ZFGCWD		*/
+extern	char oscwd[];
+
 
 /* ZFCHDR -- Change the current working directory.  Save directory name,
  * excluding the trailing "/", in oscwd so that a subsequent call to ZFGCWD
  * will be able to return directory name without a big hassle.
  */
-ZFCHDR (newdir, status)
-PKCHAR	*newdir;
-XINT	*status;
+int
+ZFCHDR (
+  PKCHAR  *newdir,
+  XINT	  *status
+)
 {
 	register char *ip, *op;
 	char	dirname[SZ_PATHNAME];
 
+
 	/* Change pathnames like "a/b/c/" to "a/b/c".
 	 */
 	for (ip=(char *)newdir, op=dirname;  (*op = *ip++) != EOS;  op++)
@@ -48,4 +52,6 @@ XINT	*status;
 	    for (ip=dirname;  (*op++ = *ip++);  )
 		;
 	}
+
+	return (*status);
 }
