@@ -9,8 +9,14 @@
 #include <iraf.h>
 
 
-extern  int  ZOPNTX (), ZCLSTX (), ZFLSTX (), ZGETTX ();
-extern  int  ZNOTTX (), ZPUTTX (), ZSEKTX (), ZSTTTX ();
+extern  int ZOPNTX (PKCHAR *osfn, XINT *mode, XINT *chan);
+extern	int ZCLSTX (XINT *fd, XINT *status);
+extern	int ZFLSTX (XINT *fd, XINT *status);
+extern	int ZGETTX (XINT *fd, XCHAR *buf, XINT *maxchars, XINT *status);
+extern  int ZNOTTX (XINT *fd, XLONG *offset);
+extern	int ZPUTTX (XINT *fd, XCHAR *buf, XINT *nchars, XINT *status);
+extern	int ZSEKTX (XINT *fd, XLONG *znottx_offset, XINT *status);
+extern	int ZSTTTX (XINT *fd, XINT *param, XLONG *value);
 
 
 /*
