@@ -24,7 +24,7 @@ ZFRNAM (
 	static	XINT setprot    = SET_PROTECTION;
 	XINT	protected;
 
-	extern  int ZFPROT();
+	extern  int ZFPROT(PKCHAR *fname, XINT *action, XINT *status);
 
 
 	/* Most remove file protection before renaming the file, else
